CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
59 lines
1.6 KiB
Plaintext
59 lines
1.6 KiB
Plaintext
// REQUIRES: x86-registered-target
|
|
// REQUIRES: nvptx-registered-target
|
|
|
|
// Make sure we handle target overloads correctly. Most of this is checked in
|
|
// sema, but special functions like constructors and destructors are here.
|
|
//
|
|
// RUN: %clang_cc1 -triple x86_64-unknown-linux-gnu -emit-llvm -o - %s \
|
|
// RUN: | FileCheck -check-prefix=CHECK-BOTH -check-prefix=CHECK-HOST %s
|
|
// RUN: %clang_cc1 -triple nvptx64-nvidia-cuda -fcuda-is-device -emit-llvm -o - %s \
|
|
// RUN: | FileCheck -check-prefix=CHECK-BOTH -check-prefix=CHECK-DEVICE %s
|
|
|
|
#include "Inputs/cuda.h"
|
|
|
|
// Check constructors/destructors for D/H functions
|
|
#ifdef __CUDA_ARCH__
|
|
__device__
|
|
#endif
|
|
int x;
|
|
struct s_cd_dh {
|
|
__host__ s_cd_dh() { x = 11; }
|
|
__device__ s_cd_dh() { x = 12; }
|
|
};
|
|
|
|
struct s_cd_hd {
|
|
__host__ __device__ s_cd_hd() { x = 31; }
|
|
__host__ __device__ ~s_cd_hd() { x = 32; }
|
|
};
|
|
|
|
// CHECK-BOTH: define{{.*}} void @_Z7wrapperv
|
|
#if defined(__CUDA_ARCH__)
|
|
__device__
|
|
#else
|
|
__host__
|
|
#endif
|
|
void wrapper() {
|
|
s_cd_dh scddh;
|
|
// CHECK-BOTH: call void @_ZN7s_cd_dhC1Ev(
|
|
s_cd_hd scdhd;
|
|
// CHECK-BOTH: call void @_ZN7s_cd_hdC1Ev
|
|
|
|
// CHECK-BOTH: call void @_ZN7s_cd_hdD1Ev(
|
|
}
|
|
// CHECK-BOTH: ret void
|
|
|
|
// Now it's time to check what's been generated for the methods we used.
|
|
|
|
// CHECK-BOTH: define linkonce_odr void @_ZN7s_cd_dhC2Ev(
|
|
// CHECK-HOST: store i32 11,
|
|
// CHECK-DEVICE: store i32 12,
|
|
// CHECK-BOTH: ret void
|
|
|
|
// CHECK-BOTH: define linkonce_odr void @_ZN7s_cd_hdC2Ev(
|
|
// CHECK-BOTH: store i32 31,
|
|
// CHECK-BOTH: ret void
|
|
|
|
// CHECK-BOTH: define linkonce_odr void @_ZN7s_cd_hdD2Ev(
|
|
// CHECK-BOTH: store i32 32,
|
|
// CHECK-BOTH: ret void
|